@@ -7,19 +7,24 @@ from time import time
 from threading import current_thread
 
 from pwbus.engines.engine_monitor_event import EngineMonitorEvent
-
+from pwbus.commons.cprint import cprint
 from sys import stdout, exit
 
 LOG_DEBUG = True
 LOG_ERROR = True
 
+
 # logging.print_datetime
 #
-
-
 def print_datetime(arg1, arg2=''):
-    print(current_thread().getName(), datetime.now().strftime(
-        '%Y-%m-%d %H:%M:%S.%f'), f'{arg1} {arg2}')
+    cprint(
+        f'{current_thread().getName()} {datetime.now().strftime("%Y-%m-%d %H:%M:%S.%f")}'
+        color='cyan',
+    cprint(
+        arg1,
+        color='bright_white'
+    )
+    print(f' {arg2}')
 
 # logging.getMillis
 #
@@ -74,7 +79,7 @@ def log_error(traceback, message):
     EngineMonitorEvent().pushEvent(
         {"type": "error", "message": message, "exception": traceback.format_exc()})
     if LOG_DEBUG:
-        formatted_lines = traceback.format_exc().splitlines()
+        formatted_lines=traceback.format_exc().splitlines()
         print_datetime(
             f'ERROR## 🟥 {message}\n     ## Message: {formatted_lines[-1]}')
         traceback.print_exc()
@@ -121,4 +126,3 @@ def log_warn(arg1, arg2=''):
         if arg2 != '':
             print_datetime('     ::', arg2)
         stdout.flush()
-
