@@ -23,20 +23,26 @@ class DynamicTask():
         except:
             log_debug(
                 f'🟥 DynamicTask - Invalid task_id [{task_id}] specify "module.class" (lowercase)')
+            payload['errorOnTask'] = f'Invalid task_id [{task_id}]'
             return
 
         try:
-            module = importlib.import_module(module_name)
-            class_ = getattr(module, class_name)
-            self.instance = class_(payload)
-
+            cprint(
+            module=importlib.import_module(module_name)
+            class_=getattr(module, class_name)
+            print()
+            self.instance=class_(payload)
             if isDebugEnabled:
                 log_debug(
                     f'DynamicTask - Module [{module_name}] Class [{class_name}] instance created')
+            print()
 
         except:
+            formatted_lines=traceback.format_exc().splitlines()
             log_debug(
-                f'⚠️ DynamicTask - WARNING!!! Class not found or with errors for task_id [{task_id}]')
+                f'⚠️ DynamicTask - WARNING!!! Cannot instatiate class -  task_id [{task_id}] - Message: {formatted_lines[-2]} | {formatted_lines[-1]}')
+            payload['errorOnTask']=formatted_lines[-1]
+
             traceback.print_exc()
             raise
 
